OwnedFd

Struct OwnedFd 

1.66.0 ยท Source
pub struct OwnedFd { /* private fields */ }
Available on Hermit or Motor OS or Trusty or Unix or WASI only.
An owned file descriptor.

This closes the file descriptor on drop. It is guaranteed that nobody else will close the file descriptor.

This uses repr(transparent) and has the representation of a host file descriptor, so it can be used in FFI in places where a file descriptor is passed as a consumed argument or returned as an owned value, and it never has the value -1.

You can use AsFd::as_fd to obtain a BorrowedFd.

Implementations

Source

impl OwnedFd

1.63.0 ยท Source

pub fn try_clone(&self) -> Result<Self>

Creates a new OwnedFd instance that shares the same underlying file description as the existing OwnedFd instance.